# Image PHash Tools

Based on perceptual hash, it bring some commands to your terminal.  

## Features  

- imgHash : print perceptual hash of a given image file name.


## Install

From PyPI
```
pip install img-phash-tools
```

From source  
```
pip install -r requirements.txt
pip install .
```

## imgPHash



## Dev install  

All you need is into
```
./scripts/install.dev.sh
```
It will create main venv and venv for each python version we need to tests.  

You can now run lint and check scripts:
```
./scripts/lint.sh
./scripts/tests.sh
```
